==> cmsmadesimple-1.5.3-full.tar.gz: modules/TinyMCE/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG ';
$lang['uninstalled'] = 'Modul avinstallert.';
$lang['installed'] = 'Modulversjon %s er installert';
$lang['stripbackgroundtags'] = 'Fjern bakgrunnstagger fra stilark(CSS)';
$lang['source_formatting_text'] = 'Benytt kildeformatering for den viste HTML';
$lang['dropdownblockformats_text'] = 'Blokkformater i nedtrekksmeny';
$lang['allowtables'] = 'Tillat tabell funksjoner';
$lang['newlinestyle_text'] = 'Stil for ny linje';
$lang['pstyle'] = 'p stil';
$lang['brstyle'] = 'br stil';
$lang['usecompressiontext'] = 'Benytt gz komprimering';
$lang['usecompressionhelp'] = 'Dette kan forbedre lastingen av TinyMCE, men kan ogs&aring; hindre den &aring; laste p&aring; enkelte systemer. Benytt med forsiktighet.';
$lang['forcedrootblocktext'] = 'Tving   p  rootblokk';
$lang['forcedrootblockhelp'] = 'Tvinger det returnerte innholdet til i det minste &aring; v&aelig;re omsluttet av en  p -tagg';
$lang['filepickerstyle'] = 'Filvelger stil';
$lang['filepickersize'] = 'Filvelger st&oslash;rrelse';
$lang['allowuploadtext'] = 'Tillat opplasting og oppretting av kataloger i FilePicker';
$lang['cannotreadconfig'] = 'Klarer ikke &aring; lese filen tinyconfig.php direkte s&aring; sannsynlig vil ikke TinyMCE fungere. Du b&oslash;r sjekke rettighetene p&aring; fila og foreldremappene, som b&oslash;r v&aelig;re lesbar for alle men kun skrivbar for eier.';
$lang['filenameonly'] = 'Vis filnavn';
$lang['thumbnailsonly'] = 'Vis miniatyrbilder';
$lang['showthumbnailfilestext'] = 'Vis miniatyrbilde(thumbnail)-filer i listen';
$lang['filenameandthumbnails'] = 'Vis b&aring;de filnavn og miniatyrbilder';
$lang['skinstext'] = 'Skall';
$lang['skinvariationtext'] = 'Skall variasjon';
$lang['advancedwarning'] = '<strong>Vennligst bemerk!<br/>&Aring; endre disse innstillingene kan f&aring; TinyMCE til &aring; slutte &aring; virke eller den genererte koden kan bli feil p&aring; en eller annen m&aring;te. Rediger dette bare om du vet hva du gj&oslash;r! Vennligst konsulter TinyMCE nettsiden f&oslash;r du leker deg med dette.</strong>';
$lang['entityencoding_text'] = 'Enkoding av entiteter';
$lang['rawencoding'] = 'Raw enkoding (raskest, fungerer i de fleste tilfeller)';
$lang['namedencoding'] = 'Navngitt enkoding (som &nbsp;)';
$lang['numericencoding'] = 'Numerisk enkoding (som &amp;#160;)';
$lang['show_path_text'] = 'Vis stien til et element nederst i editoren.';
$lang['toolbar_tab'] = 'Verkt&oslash;ylinje';
$lang['toolbar_help'] = 'Disse valgene skal inneholde en kommaseparert liste med navn p&aring; knapper som skal vises i verkt&oslash;ylinjen.';
$lang['toolbar_text'] = 'Verkt&oslash;ylinje';
$lang['toolbarhelptext'] = 'Klikk her for &aring; se instruksjoner for verkt&oslash;ylinjer i TinyMCE-wiki&#039;en.';
$lang['editor_width_text'] = 'Bredde p&aring; redigeringsfelt';
$lang['editor_height_text'] = 'H&oslash;yde p&aring; redigeringsfelt';
$lang['auto'] = 'Auto ';
$lang['or'] = 'eller';
$lang['datetimeformat_text'] = 'Dato/Tids format';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Dato';
$lang['datetimeformat_help'] = 'Klikk her for &aring; f&aring; hjelp om formatet for dato/tid';
$lang['extraconfigtext'] = 'Ekstra konfigurasjon';
$lang['extraconfighelp'] = 'Se TinyMCE-wiki for instruksjoner';
$lang['customdropdowntext'] = 'Tilpasset nedtrekk';
$lang['customdropdownhelp'] = 'Setter inn sm&aring; tilpassbare snutter av kode/tekst ved &aring; velge fra en nedtrekksmeny. 
Mulig bruk er lett tilgang til tagger osv. Menyen settes inn i verkt&oslash;ylinjen ved &aring; bruke &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'P&aring;sl&aring;tt ved start';
$lang['startenabledhelp'] = 'Ved &aring; fjerne avkrysningen for denne vil Tiny-redigereren starte opp i avsl&aring;tt modus. Benyttes sammen med veksle-knappen.';
$lang['loadcmslinkertext'] = 'Last CMS-linker';
$lang['loadcmslinkerhelp'] = 'Dette genererer javascript koden som trengs for &aring; tillate cmslinker &aring; bli lagt til verkt&oslash;ylinjen.';
$lang['cmslinkerstyletext'] = 'CMS-linker lenkestil';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stil (st&oslash;tter vakre url&#039;er)';
$lang['ahrefstyle'] = '< a href >-stil (st&oslash;tter ikke vakre url&#039;er)';
$lang['relativeurlstext'] = 'Generer relative url&#039;er';
$lang['forcecleanpastetext'] = 'Tving ren innliming';
$lang['forcecleanpastehelp'] = 'Dette b&oslash;r v&aelig;re sl&aring;tt p&aring; for &aring; fjerne rare formatteringskoder n&aring;r man limer inn fra f.eks. Word.';
$lang['bodycss_text'] = 'Body tagg stilsett/CSS';
$lang['bodycss_help'] = 'Vil bli lagt til css body definisjonen. Hint: Background-color kan settes til hvit ved &aring; benytte &quot;background-color: white&quot;';
$lang['includeonlyscreencss_text'] = 'Inkluder kun screen(skjerm) CSS';
$lang['includeonlyscreencss_help'] = 'Ved &aring; velge dette tillater du at kun de tilknyttede stilark som har screen-mediatype &aring; bli inkludert i de stilene TinyMCE n&aring;ndterer.';
$lang['usestaticconfigtext'] = 'Benytt statisk config fil';
$lang['usestaticconfighelp'] = 'Dette kan hjelpe med &aring; f&aring; din Tiny til &aring; fungere p&aring; systemer hvor vertsystemet legger til stoff som f.eks. statistikk til alle viste sider, som &oslash;delegger den dynamisk opprettede javascript config filen';
$lang['usestaticconfigwarning'] = 'Advarsel! Du har sl&aring;tt p&aring; innstillingen for statisk config-fil men din /tmp/ katalog er ikke skrivbar. Dette vil forhindre modulen i &aring; lagre den statiske config-filen og vil mest sannsynlig rendere TinyMCE til ikke &aring; fungere.';
$lang['showtogglebutton_text'] = 'Vis avkryssningsboks for &aring; sl&aring; wysiwyg p&aring;/av';
$lang['togglewysiwyg'] = 'Sl&aring; WYSIWYG p&aring;/av';
$lang['styles_tab'] = 'CSS stiler';
$lang['styles_help'] = '  Hvis du lar dette feltet tomt, vil TinyMCE tolke dine CSS filer og vise stilene i disse til brukeren. 
  Hvis du bare &oslash;nsker &aring; presentere noen stiler til brukerne, kan du spesifisere dem p&aring; formen
&quot;CustomName1=style1; CustomName2=style2&quot;,
  &quot;style1&quot; er et klasse kall i ditt stilark og du hopper over    .   
  normalt benyttes dette for klasse kall(class calls) da dette allerede er i din CSS, det vil se slik ut <span class=&quot;style1&quot;>tekst</span>, 
 i det f&oslash;rste feltet nedenfor. ';
$lang['css_styles_text'] = 'Stiler';
$lang['accessdenied'] = 'Ikke tilgang. Sjekk om du har rettigheter til dette.';
$lang['error'] = 'Feil!';
$lang['submit'] = 'Utf&oslash;r';
$lang['update'] = 'Oppdater';
$lang['settings'] = 'Innstillinger';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['advancedsaved'] = 'Avanserte innstillinger lagret';
$lang['toolbarsaved'] = 'Verkt&oslash;ylinjen ble lagret';
$lang['stylessaved'] = 'Stiler ble lagret';
$lang['testareatext'] = 'Testomr&aring;de, intet innhold vill bli ber&oslash;rt n&aring;r du roter her...';
$lang['reset'] = 'Tilbakestill til standard';
$lang['resetall'] = 'Tilbakestill alle innstillinger til standard';
$lang['confirmreset'] = 'Er du virkelig sikker p&aring; at du vil tilbakestille disse funksjonene til deres standard?';
$lang['confirmresetall'] = 'Er du sikker p&aring; at du vil tilbakestille ALLE innstillinger til deres standard?';
$lang['settingsreset'] = 'Disse innstillingene ble tilbakestilt til standard';
$lang['allsettingsreset'] = 'Alle innstillinger ble tilbakestilt til standard';
$lang['upgraded'] = 'har blitt oppgradert til versjon %s';
$lang['customdropdown'] = 'Tilpasset nedtrekksmeny';
$lang['cmsmslinker'] = 'Sett inn lenke til cmsms side';
$lang['backend_toolbars'] = 'Backend verkt&oslash;ylinje innstillinger';
$lang['frontend_toolbars'] = 'Frontend verkt&oslash;ylinje innstillinger';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Velg de plugins du vil aktivere. Dokumentasjon kan du finne <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">her</a>';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Lagre plugins';
$lang['pluginssaved'] = 'Plugins lagret';
$lang['youareintext'] = 'Du er i';
$lang['loadstylesheettext'] = 'Last stilark for innhold (anbefalt)';
$lang['extrastylestext'] = 'Tillegg til stilark';
$lang['extrastyleshelp'] = 'CSS du setter inn her vil bli lagt til stilarket som leses av TinyMCE - etter TinyMCE mottar stilene fra CMSms';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Last opp';
$lang['createnewdir'] = 'Ny katalog';
$lang['createdir'] = 'Opprett';
$lang['nodirname'] = 'Ingen katalognavn oppgitt';
$lang['direxists'] = 'Katalognavn eksisterer allerede';
$lang['newdircreated'] = 'Ny katalog opprettet';
$lang['newdirfailed'] = 'Feil oppstod ved fors&oslash;k p&aring; &aring; opprette katalog';
$lang['nofile'] = 'Ingen fil ble lastet opp';
$lang['filetoobig'] = 'Opplastet fil er for stor';
$lang['uploadfailed'] = 'Feil ved flytting av opplastet fil til sin plassering';
$lang['fileuploaded'] = 'Fill vellykket lastet opp';
$lang['filepickertitle'] = 'CMSMadeSimple Fil-velger';
$lang['success'] = 'Vellykket';
$lang['fileoperations'] = 'Filoperasjoner';
$lang['thousanddelimiter'] = ' ';
$lang['size'] = 'St&oslash;rrelse';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avansert';
$lang['help'] = '	<h3>Hva gj&oslash;r denne modulen?</h3>
	<p>Gj&oslash;r det mulig &aring; bruke TinyMCE som WYSIWYG tekstbehandler.</p>
	<h3>Hvordan bruker jeg den?</h3>
	<p>Installer den, g&aring; deretter til System - Brukervalg og velg TinyMCE som din WYSIWYG tekstbehandler.</p>
<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>
	<li>2. Try to switch on the Static Config option. Note that this requires your /tmp/-dir to be writable by the webserver</li>
	<li>3. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changes from 2.3.x to 2.4.x series of the module.
	<li>4. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based)
	</ul>
	<br/>
		';
$lang['utmz'] = '156861353.1232831699.848.25.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utma'] = '156861353.179052623084110100.1210423577.1233960823.1234022375.893';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.3.10.1234022375';
?>

==> cmsmadesimple-1.7.1-full.tar.gz: modules/TinyMCE/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'TinyMCE WYSIWYG ';
$lang['uninstalled'] = 'Modul avinstallert.';
$lang['installed'] = 'Modulversjon %s er installert';
$lang['stripbackgroundtags'] = 'Fjern bakgrunnstagger fra stilark(CSS)';
$lang['stiptags_help'] = 'Disse valgene fors&oslash;ker &aring; fjerne innstillinger av typen background fra stilarket.';
$lang['source_formatting_text'] = 'Benytt kildeformatering for den viste HTML';
$lang['dropdownblockformats_text'] = 'Blokkformater i nedtrekksmeny';
$lang['allowtables'] = 'Tillat tabell funksjoner';
$lang['newlinestyle_text'] = 'Stil for ny linje';
$lang['pstyle'] = 'p stil';
$lang['brstyle'] = 'br stil';
$lang['usecompressiontext'] = 'Benytt gz komprimering';
$lang['usecompressionhelp'] = 'Dette kan forbedre lastingen av TinyMCE, men kan ogs&aring; hindre den &aring; laste p&aring; enkelte systemer. Benytt med forsiktighet.';
$lang['forcedrootblocktext'] = 'Tving   p  rootblokk';
$lang['forcedrootblockhelp'] = 'Tvinger det returnerte innholdet til i det minste &aring; v&aelig;re omsluttet av en  p -tagg';
$lang['filepickerstyle'] = 'Filvelger stil';
$lang['filepickersize'] = 'Filvelger st&oslash;rrelse';
$lang['allowuploadtext'] = 'Tillat opplasting og oppretting av kataloger i FilePicker';
$lang['allowscalingtext'] = 'Tillat endring av st&oslash;rrelse p&aring; opplastede filer on-the-fly';
$lang['scalingdimensionstext'] = 'Standard dimensjoner';
$lang['resizeto'] = 'Endre st&oslash;rrelse til:';
$lang['makethumbnail'] = 'Opprett miniatyrbilde n&aring;r bilde lastes opp';
$lang['useadvancedprofile'] = 'Benytt avansert TinyMCE-profil';
$lang['saveprofile'] = 'Lagre profil';
$lang['profilesaved'] = 'Profilen ble lagret';
$lang['profiles_tab'] = 'Profiler';
$lang['advanced_backend_toolbars'] = 'Avanserte backend profilinnstillinger';
$lang['savestyles'] = 'Lagre stiler';
$lang['allowadvancedprofile'] = 'Tillat bruk av avanserte profiler i TinyMCE';
$lang['showfilemanagement'] = 'Vis filbehandlingsvalg';
$lang['showfilemanagementhelp'] = 'Vis filbehandlingsvalg som opplasting, opprette katalog og sletting av fil i FilePicker, om brukeren har tillatelse til &aring; utf&oslash;re disse.';
$lang['restrictdirs'] = 'Begrens brukers tilgang til kataloger';
$lang['restrictdirshelp'] = 'Dette vil begrense filbehandlingsegenskapene til brukeren til kun en underkatalog av &quot;uploads&quot; som har samme navn som brukerens p&aring;loggingsnavn. Hvis underkatalogen ikke eksisterer, vil den muligens bli opprettet. V&aelig;r oppmerksom p&aring; at dette forel&oslash;pig bare fungerer med standard katalognavn, uploads / images. Dette kan endre seg i fremtiden.';
$lang['deleteconfirmation'] = 'Er du sikker p&aring; at denne filen skal slettes?';
$lang['deletefilesuccess'] = 'ble vellykket slettet';
$lang['deletefilefailed'] = 'kunne ikke slettes';
$lang['deletesubdirfailed'] = 'kunne ikke slettes';
$lang['deletesubdirsuccess'] = 'ble vellykket slettet';
$lang['deletedirconfirmation'] = 'Er du sikker p&aring; at denne tomme underkatalogen skal slettes?';
$lang['deletedir'] = 'Slett eom underkatalog';
$lang['deletefile'] = 'Slett fil';
$lang['cannotreadconfig'] = 'Klarer ikke &aring; lese filen tinyconfig.php direkte s&aring; sannsynligvis vil ikke TinyMCE fungere. Du b&oslash;r sjekke rettighetene p&aring; fila og foreldremappene, som b&oslash;r v&aelig;re lesbar for alle men kun skrivbar for eier.';
$lang['filenameonly'] = 'Vis filnavn';
$lang['thumbnailsonly'] = 'Vis miniatyrbilder';
$lang['showthumbnailfilestext'] = 'Vis miniatyrbilde(thumbnail)-filer i listen';
$lang['filenameandthumbnails'] = 'Vis b&aring;de filnavn og miniatyrbilder';
$lang['skinstext'] = 'Skall';
$lang['skinvariationtext'] = 'Skall variasjon';
$lang['advancedwarning'] = '<strong>Vennligst bemerk!<br/>&Aring; endre disse innstillingene kan f&aring; TinyMCE til &aring; slutte &aring; virke eller den genererte koden kan bli feil p&aring; en eller annen m&aring;te. Rediger dette bare om du vet hva du gj&oslash;r! Vennligst konsulter TinyMCE nettsiden f&oslash;r du leker deg med dette.</strong>';
$lang['entityencoding_text'] = 'Enkoding av entiteter';
$lang['rawencoding'] = 'Raw enkoding (raskest, fungerer i de fleste tilfeller)';
$lang['namedencoding'] = 'Navngitt enkoding (som &nbsp;)';
$lang['numericencoding'] = 'Numerisk enkoding (som &amp;#160;)';
$lang['show_path_text'] = 'Vis stien til et element nederst i editoren.';
$lang['toolbar_tab'] = 'Verkt&oslash;ylinje';
$lang['toolbar_help'] = 'Disse valgene skal inneholde en kommaseparert liste med navn p&aring; knapper som skal vises i verkt&oslash;ylinjen. Tegnet  1  kan benyttes i stedet for ordet &#039;separator&#039;';
$lang['toolbar_text'] = 'Verkt&oslash;ylinje';
$lang['toolbarhelptext'] = 'Klikk her for &aring; se instruksjoner for verkt&oslash;ylinjer i TinyMCE-wiki&#039;en.';
$lang['editor_width_text'] = 'Bredde p&aring; redigeringsfelt';
$lang['editor_height_text'] = 'H&oslash;yde p&aring; redigeringsfelt';
$lang['auto'] = 'Auto ';
$lang['or'] = 'eller';
$lang['allowresizing'] = 'Tillat p&aring;-stedet st&oslash;rrelessendring av redigeringsfeltet';
$lang['resizenone'] = 'Ikke tillat st&oslash;rrelsesendring';
$lang['resizeboth'] = 'Tillat st&oslash;rrelsesendring i begge retninger';
$lang['resizeheight'] = 'Tillat st&oslash;rrelsesendring av kun h&oslash;yden';
$lang['datetimeformat_text'] = 'Dato/Tids format';
$lang['timetext'] = 'Tid';
$lang['datetext'] = 'Dato';
$lang['datetimeformat_help'] = 'Klikk her for &aring; f&aring; hjelp om formatet for dato/tid';
$lang['extraconfigtext'] = 'Ekstra konfigurasjon';
$lang['extraconfighelp2'] = '&Eacute;n uttalelse per linje, komma vil bli lagt til f&oslash;r og etter dette innholdet. Sjekk TinyMCE-wiki for instruksjoner.';
$lang['customdropdowntext'] = 'Tilpasset nedtrekk';
$lang['customdropdownhelp'] = 'Setter inn sm&aring; tilpassbare snutter av kode/tekst ved &aring; velge fra en nedtrekksmeny. 
Mulig bruk er lett tilgang til tagger osv. Menyen settes inn i verkt&oslash;ylinjen ved &aring; bruke &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'P&aring;sl&aring;tt ved start';
$lang['startenabledhelp'] = 'Ved &aring; fjerne avkrysningen for denne vil Tiny-redigereren starte opp i avsl&aring;tt modus. Benyttes sammen med veksle-knappen.';
$lang['loadcmslinkertext'] = 'Last CMS-linker';
$lang['loadcmslinkerhelp'] = 'Dette genererer javascript koden som trengs for &aring; tillate cmslinker &aring; bli lagt til verkt&oslash;ylinjen.';
$lang['cmslinkerstyletext'] = 'CMS-linker lenkestil';
$lang['cmsselflinkstyle'] = '{cms_selflink}-stil (st&oslash;tter vakre url&#039;er)';
$lang['ahrefstyle'] = '< a href >-stil (st&oslash;tter ikke vakre url&#039;er)';
$lang['relativeurlstext'] = 'Generer relative url&#039;er';
$lang['forcecleanpastetext'] = 'Tving ren innliming';
$lang['forcecleanpastehelp'] = 'Dette b&oslash;r v&aelig;re sl&aring;tt p&aring; for &aring; fjerne rare formatteringskoder n&aring;r man limer inn fra f.eks. Word.';
$lang['bodycss_text'] = 'Body tagg stilsett/CSS';
$lang['bodycss_help'] = 'Vil bli lagt til css body definisjonen. Hint: Background-color kan settes til hvit ved &aring; benytte &quot;background-color: white&quot;';
$lang['includeonlyscreencss_text'] = 'Inkluder kun screen(skjerm) CSS';
$lang['includeonlyscreencss_help'] = 'Ved &aring; velge dette tillater du at kun de tilknyttede stilark som har avkrysset screen-mediatype &aring; bli inkludert i de stilene TinyMCE n&aring;ndterer.';
$lang['usestaticconfigtext'] = 'Benytt statisk config fil';
$lang['usestaticconfighelp'] = 'Dette kan hjelpe med &aring; f&aring; din Tiny til &aring; fungere p&aring; systemer hvor vertsystemet legger til stoff som f.eks. statistikk til alle viste sider, som &oslash;delegger den dynamisk opprettede javascript config filen';
$lang['usestaticconfigwarning'] = 'Advarsel! Du har sl&aring;tt p&aring; innstillingen for statisk config-fil men din /tmp/ katalog er ikke skrivbar. Dette vil forhindre modulen i &aring; lagre den statiske config-filen og vil mest sannsynlig rendere TinyMCE til ikke &aring; fungere.';
$lang['ignoremodifyfilestext'] = 'Ignorer &#039;Modify Files&#039; tillatelsen for FilePicker';
$lang['ignoremodifyfileshelp'] = 'Advarsel! Dette tillater noen filbehandlingsoperasjoner selv om
&#039;Modify Files&#039; tillatelsen ikke er satt for den aktuelle brukergruppen. Dette kan v&aelig;re kjekt &aring; benytte sammen med muligheten til &aring; begrense brukerens katalogtilgang.';
$lang['showtogglebutton_text'] = 'Vis avkryssningsboks for &aring; sl&aring; wysiwyg p&aring;/av';
$lang['togglewysiwyg'] = 'Sl&aring; WYSIWYG p&aring;/av';
$lang['styles_tab'] = 'CSS stiler';
$lang['styles_help'] = '  Hvis du lar dette feltet tomt, vil TinyMCE tolke dine CSS filer og vise stilene i disse til brukeren. 
  Hvis du bare &oslash;nsker &aring; presentere noen stiler til brukerne, kan du spesifisere dem p&aring; formen
&quot;CustomName1=style1; CustomName2=style2&quot;,
  &quot;style1&quot; er et klasse kall i ditt stilark og du hopper over    .   
  normalt benyttes dette for klasse kall(class calls) da dette allerede er i din CSS, det vil se slik ut <span class=&quot;style1&quot;>tekst</span>, 
 i det f&oslash;rste feltet nedenfor. ';
$lang['css_styles_text'] = 'Stiler';
$lang['accessdenied'] = 'Ikke tilgang. Sjekk om du har rettigheter til dette.';
$lang['error'] = 'Feil!';
$lang['submit'] = 'Utf&oslash;r';
$lang['update'] = 'Oppdater';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['settings'] = 'Innstillinger';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['saveadvanced'] = 'Lagre avanserte innstillinger';
$lang['advancedsaved'] = 'Avanserte innstillinger lagret';
$lang['toolbarsaved'] = 'Verkt&oslash;ylinjen ble lagret';
$lang['stylessaved'] = 'Stiler ble lagret';
$lang['testareatext'] = '<p>Testomr&aring;de, intet innhold vill bli ber&oslash;rt n&aring;r du roter her...</p>';
$lang['reset'] = 'Tilbakestill til standard';
$lang['resetall'] = 'Tilbakestill alle innstillinger til standard';
$lang['confirmreset'] = 'Er du virkelig sikker p&aring; at du vil tilbakestille disse funksjonene til deres standard?';
$lang['confirmresetall'] = 'Er du sikker p&aring; at du vil tilbakestille ALLE innstillinger til deres standard?';
$lang['settingsreset'] = 'Disse innstillingene ble tilbakestilt til standard';
$lang['allsettingsreset'] = 'Alle innstillinger ble tilbakestilt til standard';
$lang['upgraded'] = 'har blitt oppgradert til versjon %s';
$lang['customdropdown'] = 'Tilpasset nedtrekksmeny';
$lang['cmsmslinker'] = 'Sett inn lenke til cmsms side';
$lang['backend_toolbars'] = 'Backend verkt&oslash;ylinje innstillinger';
$lang['frontend_toolbars'] = 'Frontend verkt&oslash;ylinje innstillinger';
$lang['plugins_tab'] = 'Plugins ';
$lang['plugins_help'] = 'Velg de plugins du vil aktivere. Dokumentasjon kan du finne <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">her</a>';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Lagre plugins';
$lang['plugins_module'] = 'Modul Plugins';
$lang['plugins_common'] = 'Vanlige Plugins';
$lang['module'] = 'Modul';
$lang['description'] = 'Beskrivelse';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'Du er i';
$lang['loadstylesheettext'] = 'Last stilark for innhold (anbefalt)';
$lang['extrastylestext'] = 'Tillegg til stilark';
$lang['extrastyleshelp'] = 'CSS du setter inn her vil bli lagt til stilarket som leses av TinyMCE - etter TinyMCE mottar stilene fra CMSms';
$lang['uploadnewfile'] = 'Ny fil';
$lang['uploadfile'] = 'Last opp';
$lang['createnewdir'] = 'Ny katalog';
$lang['createdir'] = 'Opprett';
$lang['nodirname'] = 'Ingen katalognavn oppgitt';
$lang['direxists'] = 'Katalognavn eksisterer allerede';
$lang['newdircreated'] = 'Ny katalog opprettet';
$lang['newdirfailed'] = 'Feil oppstod ved fors&oslash;k p&aring; &aring; opprette katalog';
$lang['nofile'] = 'Ingen fil ble lastet opp';
$lang['filetoobig'] = 'Opplastet fil er for stor';
$lang['containsillegalchars'] = 'Filnavnet inneholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Feil ved flytting av opplastet fil til sin plassering';
$lang['fileuploaded'] = 'Fill vellykket lastet opp';
$lang['filepickertitle'] = 'CMSMadeSimple Fil-velger';
$lang['success'] = 'Vellykket';
$lang['fileoperations'] = 'Filoperasjoner';
$lang['thousanddelimiter'] = ' ';
$lang['size'] = 'St&oslash;rrelse';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Avansert';
$lang['help'] = '	<h3>Hva gj&oslash;r denne modulen?</h3>
	<p>Gj&oslash;r det mulig &aring; bruke TinyMCE som WYSIWYG tekstbehandler.</p>
	<h3>Hvordan bruker jeg den?</h3>
	<p>Installer den, g&aring; deretter til System - Brukervalg og velg TinyMCE som din WYSIWYG tekstbehandler.</p>
  <h3>Spellchecker</h3>
  <p>As of version 2.6.0, TinyMCE includes an online spellchecker. Please notice that SSL must be turned on in your server-configuration in order for this to work. On some setups this option is called php_openssl but that may vary</p>
	<h3>Troubleshooting</h3>
	Some people have trouble with tiny not showing up upon installation or upgrading. Here is a checklist of 
	things you can try before contacting me for further support.
	<br/>
	<ul>
	<li>1. Please, please, try to reupload the modules/TinyMCE dir to your server. You&#039;d be amazed how many times this has helped people.</li>	
	<li>2. If upgrading, please try to reset all settings. Not nice if you&#039;ve done a lot of customization, I know, but a lot of things changed from 2.3.x to 2.4.x series of the module.
	<li>3. Try enabling the static config option in advanced settings. This works better on some systems (like CGI-based), Note that this requires your /tmp/-dir to be writable by the webserver
	</ul>
	<br/>
  <h3>Plugin development</h3>
  As of version 2.7.0 the TinyMCE-module has the ability to allow other modules to register extensions for it. Could be a custom icon allowing you to insert
  content from some module, like Gallery etc. How to do this is pretty tech stuff, but if you are a module developer and interested in checking it out
  please look in the TinyMCE/docs-dir for further instructions.';
$lang['utmz'] = '156861353.1272675501.2656.57.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
$lang['utma'] = '156861353.179052623084110100.1210423577.1272720219.1272726637.2660';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1272726637';
?>
